/* A Bison parser, made by GNU Bison 3.8.2.  */

/* Bison interface for Yacc-like parsers in C

   Copyright (C) 1984, 1989-1990, 2000-2015, 2018-2021 Free Software Foundation,
   Inc.

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <https://www.gnu.org/licenses/>.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.

   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */

/* DO NOT RELY ON FEATURES THAT ARE NOT DOCUMENTED in the manual,
   especially those whose name start with YY_ or yy_.  They are
   private implementation details that can be changed or removed.  */

#ifndef YY_YY_DEXPR_PARSER_H_INCLUDED
# define YY_YY_DEXPR_PARSER_H_INCLUDED
/* Debug traces.  */
#ifndef YYDEBUG
# define YYDEBUG 0
#endif
#if YYDEBUG
extern int yydebug;
#endif

/* Token kinds.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
  enum yytokentype
  {
    YYEMPTY = -2,
    YYEOF = 0,                     /* "end of file"  */
    YYerror = 256,                 /* error  */
    YYUNDEF = 257,                 /* "invalid token"  */
    TOK_EQ = 258,                  /* TOK_EQ  */
    TOK_NE = 259,                  /* TOK_NE  */
    TOK_LT = 260,                  /* TOK_LT  */
    TOK_LE = 261,                  /* TOK_LE  */
    TOK_GT = 262,                  /* TOK_GT  */
    TOK_GE = 263,                  /* TOK_GE  */
    TOK_SPEC = 264,                /* TOK_SPEC  */
    TOK_STRING = 265,              /* TOK_STRING  */
    TOK_DATETIME = 266,            /* TOK_DATETIME  */
    TOK_INT = 267,                 /* TOK_INT  */
    TOK_OR = 268,                  /* TOK_OR  */
    TOK_AND = 269,                 /* TOK_AND  */
    TOK_NOT = 270,                 /* TOK_NOT  */
    TOK_LPAREN = 271,              /* TOK_LPAREN  */
    TOK_RPAREN = 272               /* TOK_RPAREN  */
  };
  typedef enum yytokentype yytoken_kind_t;
#endif
/* Token kinds.  */
#define YYEMPTY -2
#define YYEOF 0
#define YYerror 256
#define YYUNDEF 257
#define TOK_EQ 258
#define TOK_NE 259
#define TOK_LT 260
#define TOK_LE 261
#define TOK_GT 262
#define TOK_GE 263
#define TOK_SPEC 264
#define TOK_STRING 265
#define TOK_DATETIME 266
#define TOK_INT 267
#define TOK_OR 268
#define TOK_AND 269
#define TOK_NOT 270
#define TOK_LPAREN 271
#define TOK_RPAREN 272

/* Value type.  */
#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
union YYSTYPE
{
#line 85 "dexpr-parser.y"

	dexpr_t dex;
	char *sval;

#line 106 "dexpr-parser.h"

};
typedef union YYSTYPE YYSTYPE;
# define YYSTYPE_IS_TRIVIAL 1
# define YYSTYPE_IS_DECLARED 1
#endif




int yyparse (dexpr_t *cur);


#endif /* !YY_YY_DEXPR_PARSER_H_INCLUDED  */
